#!/bin/sh

set -e

# This is an install/update script for DebianParl
# DebianParl Homepage: https://wiki.debian.org/DebianParl
# Source of this code: git://git.debian.org/parl/blends

# Workaround for dictionaries-common install failure (bug#751367)
aptitude install apt-utils

# Administration
#  * include package usage reporting Popularity-Contest
#  * include APT hook apt-listchanges
#  * include APT hook needrestart
# Console
#  * include console compression tools
#  * include filesystem-related console helper tools
#  * include media-related console helper tools
#  * include network-related console helper tools
#  * install console file manager Midnight Commander
# Console-based design tools
#  * include Scour, gtk-vector-screenshot and other SVG tools
#  * include Scrot (SCReen shOT), pngcrush and other bitmap tools
#  * include pdfposter and other PDF tools
# Console media
#  * include core ALSA audio tools
#  * include PulseAudio console tools
# Console web
#  * include console web helper tools
# Desktop
#  * include GNOME system tools
#  * include GNOME-oriented NetworkManager client
#  * include screensaver unicode-screensaver
# Desktop design
#  * include color pickers Gcolor2 and Gpick
#  * include 2D vector-based drawing application Inkscape
#  * include Desktop Publishing application Scribus
#  * include GTK+ font tools
#  * include painting applications GIMP and MyPaint, with add-ons
#  * include PDF tools PDF-Shuffler, Origami and DiffPDF
# Desktop email
#  * include Thunderbird email client
#  * include Thunderbird sieve plugin
# desktop-environment-xfce
#  * include the lightweight Xfce desktop
#  * include Xfce power management tools
#  * include Xfce file manager
#  * include Xfce notification manager
#  * exclude Xfce audio handling
# Desktop media
#  * include simple ALSA volume control Volti
#  * include PulseAudio desktop volume control
#  * include video player Mpv
#  * exclude PulseAudio wrapper for legacy audio system EsounD
#  * exclude video player MPlayer2
# Desktop office
#  * include document viewer Evince
#  * include spreadsheet application Gnumeric
#  * include word processor AbiWord
#  * include LibreOffice theme tango
#  * include LibreOffice integration with GTK+ 2.x
#  * include LibreOffice Writer
#  * include LibreOffice Calc
#  * include LibreOffice Impress
# Desktop photo
#  * include photo manager Shotwell
# Desktop scheduling
#  * include Thunderbird extension Lightning
# Desktop web
#  * include Firefox web browser
# Framework
#  * include Tango icon theme
#  * include Xfce themes for GTK+ 2.0
# Documentation framework
#  * include Info browser
#  * include man browser
#  * include core man pages
# Package framework
#  * include command-line and Curses APT frontend aptitude
# Version control system
#  * include VCS tool git
#  * include VCS metatool mr
# Hardware
#  * include OpenGL hardware rasterizers
#  * exclude OpenGL software rasterizers
# Audio service
#  * include PulseAudio audio daemon
aptitude install task-laptop abiword alsa-utils apt-listchanges aptitude buku bzip2 dfc diffpdf evince firefox-esr font-manager gcolor2 gimp gimp-lensfun gimp-plugin-registry git gnome-system-tools gnumeric gpick gtk-vector-screenshot gtk2-engines-xfce gucharmap gvfs info inkscape jpeginfo jpegoptim lcdf-typetools less libgl1-mesa-dri libpdf-reuse-perl libpodofo-utils libreoffice-calc libreoffice-gtk2 libreoffice-impress libreoffice-ogltrans libreoffice-style-tango libreoffice-writer librsvg2-bin libtiff-tools lightdm lightning links man-db manpages mc mpv mtr-tiny mypaint mypaint-data-extras myrepos ncdu needrestart network-manager-gnome origami-pdf pasystray pavucontrol pdfposter pdfshuffler pngcrush poppler-utils popularity-contest pulseaudio pulseaudio-utils python-cairosvg python-scour qpdf rsync scribus scrot shotwell tango-icon-theme thunar thunderbird typecatcher unicode-screensaver v4l-utils volti wget xfce4-notifyd xfce4-power-manager xfce4-power-manager-plugins xfce4-session xserver-xorg xul-ext-sieve \
 evince-gtk- libgl1-mesa-swx11- libreoffice-emailmerge- libreoffice-java-common- mplayer2- pulseaudio-esound-compat- xfce4-mixer- xfce4-volumed- xfce4-volumed-

# Administration
#  * define routines to make backup of and help edit config files
# desktop-environment-xfce
#  * silence confusing panel question at initial login
#  * replace appfinder with mail-reader in default panel
#  * disable storing session at logout by default
apt-mark auto \
  aptitude-common gvfs lightdm-gtk-greeter mr pulseaudio-utils xserver-xorg
 _backup(){ set -e;\
  if [ -e "$1" ]; then \
    if [ -e "$1.orig" ]; then \
      cp -a "$1" "$1.bak";\
    else \
      cp -a "$1" "$1.orig";\
    fi;\
  else \
    touch "$1.orig";\
  fi; };\
 _backup_todir(){ set -e;\
  dir="${2:-$(dirname "$1").bak}";\
  [ -e "$dir" ] || mkdir -p "$dir";\
  path="$dir/$(basename "$1")";\
  if [ -e "$1" ]; then \
    cp -fa "$1" "$path";\
  else \
    touch "$path";\
  fi; };\
 _clone(){ set -e;\
  test -e "$1";\
  _backup "$2";\
  cp -fa "$1" "$2"; };\
 _setline(){ set -e;\
  _backup "$1";\
  if [ $# = 3 ]; then \
    sed -i -r \
      -e "s!^#?($2)\$!$3!g" "$1";\
  else \
    sed -i -r \
      -e "s!^#?($2)\$!\\1!g" "$1";\
  fi; };\
 _setappendline(){ set -e;\
  if [ -e "$1" ] && egrep -q "^#?$2\$" "$1"; then \
    _setline "$@";\
  else \
    _backup "$1";\
    echo "${3:-$2}" >> "$1";\
  fi; };\
 _setvar(){ set -e;\
  _backup "$1";\
  sed -i -r \
    -e "s!^#?($2)=.*!\\1=$3!" "$1"; };\
 _setappendvar(){ set -e;\
  if [ -e "$1" ] && egrep -q "^#?$2=" "$1"; then \
    _setvar "$@";\
  else \
    _backup "$1";\
    echo "$2=$3" >> "$1";\
  fi; };\
 cd /etc/xdg/xfce4/xfconf/xfce-perchannel-xml;\
 _clone ../../panel/default.xml xfce4-panel.xml;\
 sed -i -r \
  -e 's,xfce4-appfinder,exo-mail-reader,' \
  xfce4-panel.xml;\
 _backup xfce4-session.xml;\
 sed -i -r \
  -e 's,(<property name="general"[^>]*>),\1\n    <property name="SaveOnExit" type="bool" value="false"/>,' \
  xfce4-session.xml
